@@ -1,21 +1,10 @@
-/****************************************************************************
- *    Copyright 2002  Marco Krüger <grisuji@gmx.de>                         *
- *    Copyright 2002  Ian Wadham <iandw.au@gmail.com>                       *
- *    Copyright 2009  Ian Wadham <iandw.au@gmail.com>                       *
- *                                                                          *
- *    This program is free software; you can redistribute it and/or         *
- *    modify it under the terms of the GNU General Public License as        *
- *    published by the Free Software Foundation; either version 2 of        *
- *    the License, or (at your option) any later version.                   *
- *                                                                          *
- *    This program is distributed in the hope that it will be useful,       *
- *    but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *    GNU General Public License for more details.                          *
- *                                                                          *
- *    You should have received a copy of the GNU General Public License     *
- *    along with this program.  If not, see <http://www.gnu.org/licenses/>. *
- ****************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2002 Marco Krüger <grisuji@gmx.de>
+    SPDX-FileCopyrightText: 2002 Ian Wadham <iandw.au@gmail.com>
+    SPDX-FileCopyrightText: 2009 Ian Wadham <iandw.au@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "kgoldrunner.h"
 
@@ -223,7 +212,7 @@ void KGoldrunner::setupActions()
                            i18n ("Save a solution for a level into a file "
                                  "called 'sol_&lt;prefix&gt;.txt' in your "
 				 "user's data directory..."),
-                           Qt::ShiftModifier + Qt::Key_S);
+                           {Qt::ShiftModifier | Qt::Key_S});
 
     // Pause
     // Show High Scores
@@ -290,7 +279,7 @@ void KGoldrunner::setupActions()
     // Quit
     // --------------------------
 
-    KStandardGameAction::quit (this, SLOT (close()), actionCollection());
+    KStandardGameAction::quit (this, &QWidget::close, actionCollection());
 
     /**************************************************************************/
     /***************************   GAME EDITOR MENU  **************************/
@@ -495,7 +484,7 @@ void KGoldrunner::setupActions()
     // --------------------------
 
     KStandardAction::keyBindings (
-                                this, SLOT (optionsConfigureKeys()),
+                                this, &KGoldrunner::optionsConfigureKeys,
                                 actionCollection());
 
     /**************************************************************************/
